==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkVoxelGrid.java <==
// java wrapper for vtkVoxelGrid object
//

package vtk;
import vtk.*;

public class vtkVoxelGrid extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetConfigurationStyle_2(int id0);
  public void SetConfigurationStyle(int id0)
    { SetConfigurationStyle_2(id0); }

  private native int GetConfigurationStyle_3();
  public int GetConfigurationStyle()
    { return GetConfigurationStyle_3(); }

  private native void SetConfigurationStyleToManual_4();
  public void SetConfigurationStyleToManual()
    { SetConfigurationStyleToManual_4(); }

  private native void SetConfigurationStyleToLeafSize_5();
  public void SetConfigurationStyleToLeafSize()
    { SetConfigurationStyleToLeafSize_5(); }

  private native void SetConfigurationStyleToAutomatic_6();
  public void SetConfigurationStyleToAutomatic()
    { SetConfigurationStyleToAutomatic_6(); }

  private native void SetDivisions_7(int id0,int id1,int id2);
  public void SetDivisions(int id0,int id1,int id2)
    { SetDivisions_7(id0,id1,id2); }

  private native void SetDivisions_8(int id0[]);
  public void SetDivisions(int id0[])
    { SetDivisions_8(id0); }

  private native int[]  GetDivisions_9();
  public int[]  GetDivisions()
    { return GetDivisions_9(); }

  private native void SetLeafSize_10(double id0,double id1,double id2);
  public void SetLeafSize(double id0,double id1,double id2)
    { SetLeafSize_10(id0,id1,id2); }

  private native void SetLeafSize_11(double id0[]);
  public void SetLeafSize(double id0[])
    { SetLeafSize_11(id0); }

  private native double[] GetLeafSize_12();
  public double[] GetLeafSize()
    { return GetLeafSize_12(); }

  private native void SetNumberOfPointsPerBin_13(int id0);
  public void SetNumberOfPointsPerBin(int id0)
    { SetNumberOfPointsPerBin_13(id0); }

  private native int GetNumberOfPointsPerBinMinValue_14();
  public int GetNumberOfPointsPerBinMinValue()
    { return GetNumberOfPointsPerBinMinValue_14(); }

  private native int GetNumberOfPointsPerBinMaxValue_15();
  public int GetNumberOfPointsPerBinMaxValue()
    { return GetNumberOfPointsPerBinMaxValue_15(); }

  private native int GetNumberOfPointsPerBin_16();
  public int GetNumberOfPointsPerBin()
    { return GetNumberOfPointsPerBin_16(); }

  private native void SetKernel_17(vtkInterpolationKernel id0);
  public void SetKernel(vtkInterpolationKernel id0)
    { SetKernel_17(id0); }

  private native long GetKernel_18();
  public vtkInterpolationKernel GetKernel() {
    long temp = GetKernel_18();

    if (temp == 0) return null;
    return (vtkInterpolationKernel)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkVoxelGrid() { super(); }

  public vtkVoxelGrid(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkVoxelGrid.java <==
// java wrapper for vtkVoxelGrid object
//

package vtk;
import vtk.*;

public class vtkVoxelGrid extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetConfigurationStyle_2(int id0);
  public void SetConfigurationStyle(int id0)
    { SetConfigurationStyle_2(id0); }

  private native int GetConfigurationStyle_3();
  public int GetConfigurationStyle()
    { return GetConfigurationStyle_3(); }

  private native void SetConfigurationStyleToManual_4();
  public void SetConfigurationStyleToManual()
    { SetConfigurationStyleToManual_4(); }

  private native void SetConfigurationStyleToLeafSize_5();
  public void SetConfigurationStyleToLeafSize()
    { SetConfigurationStyleToLeafSize_5(); }

  private native void SetConfigurationStyleToAutomatic_6();
  public void SetConfigurationStyleToAutomatic()
    { SetConfigurationStyleToAutomatic_6(); }

  private native void SetDivisions_7(int id0,int id1,int id2);
  public void SetDivisions(int id0,int id1,int id2)
    { SetDivisions_7(id0,id1,id2); }

  private native void SetDivisions_8(int id0[]);
  public void SetDivisions(int id0[])
    { SetDivisions_8(id0); }

  private native int[]  GetDivisions_9();
  public int[]  GetDivisions()
    { return GetDivisions_9(); }

  private native void SetLeafSize_10(double id0,double id1,double id2);
  public void SetLeafSize(double id0,double id1,double id2)
    { SetLeafSize_10(id0,id1,id2); }

  private native void SetLeafSize_11(double id0[]);
  public void SetLeafSize(double id0[])
    { SetLeafSize_11(id0); }

  private native double[] GetLeafSize_12();
  public double[] GetLeafSize()
    { return GetLeafSize_12(); }

  private native void SetNumberOfPointsPerBin_13(int id0);
  public void SetNumberOfPointsPerBin(int id0)
    { SetNumberOfPointsPerBin_13(id0); }

  private native int GetNumberOfPointsPerBinMinValue_14();
  public int GetNumberOfPointsPerBinMinValue()
    { return GetNumberOfPointsPerBinMinValue_14(); }

  private native int GetNumberOfPointsPerBinMaxValue_15();
  public int GetNumberOfPointsPerBinMaxValue()
    { return GetNumberOfPointsPerBinMaxValue_15(); }

  private native int GetNumberOfPointsPerBin_16();
  public int GetNumberOfPointsPerBin()
    { return GetNumberOfPointsPerBin_16(); }

  private native void SetKernel_17(vtkInterpolationKernel id0);
  public void SetKernel(vtkInterpolationKernel id0)
    { SetKernel_17(id0); }

  private native long GetKernel_18();
  public vtkInterpolationKernel GetKernel() {
    long temp = GetKernel_18();

    if (temp == 0) return null;
    return (vtkInterpolationKernel)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkVoxelGrid() { super(); }

  public vtkVoxelGrid(long id) { super(id); }
  public native long   VTKInit();

}
